@@ -1,12 +1,15 @@
 """Date parsing utilities."""
 
+import re
 import time
 from calendar import monthrange
 from datetime import datetime, timezone
+from io import StringIO
 from typing import Dict, Optional, Tuple
 
 import dateutil
-from dateutil.parser import ParserError, _timelex, parserinfo
+from dateutil.parser import ParserError, parserinfo
+from six import text_type
 
 default_sd_year = 1
 default_date_notz = datetime(
@@ -112,6 +115,173 @@ def get_tzinfos(timezone_info: str) -> Dict[str, int]:
 default_tzinfos = get_tzinfos(default_timezone_info)
 
 
+# Ugly copy and paste of the whole _timelex class from dateutil to prevent
+# deprecation warnings
+class _timelex(object):
+    # Fractional seconds are sometimes split by a comma
+    _split_decimal = re.compile("([.,])")
+
+    def __init__(self, instream):
+        if isinstance(instream, (bytes, bytearray)):
+            instream = instream.decode()
+
+        if isinstance(instream, text_type):
+            instream = StringIO(instream)
+        elif getattr(instream, "read", None) is None:
+            raise TypeError(
+                "Parser must be a string or character stream, not {itype}".format(
+                    itype=instream.__class__.__name__
+                )
+            )
+
+        self.instream = instream
+        self.charstack = []
+        self.tokenstack = []
+        self.eof = False
+
+    def get_token(self):
+        """
+        This function breaks the time string into lexical units (tokens), which
+        can be parsed by the parser. Lexical units are demarcated by changes in
+        the character set, so any continuous string of letters is considered
+        one unit, any continuous string of numbers is considered one unit.
+
+        The main complication arises from the fact that dots ('.') can be used
+        both as separators (e.g. "Sep.20.2009") or decimal points (e.g.
+        "4:30:21.447"). As such, it is necessary to read the full context of
+        any dot-separated strings before breaking it into tokens; as such, this
+        function maintains a "token stack", for when the ambiguous context
+        demands that multiple tokens be parsed at once.
+        """
+        if self.tokenstack:
+            return self.tokenstack.pop(0)
+
+        seenletters = False
+        token = None
+        state = None
+
+        while not self.eof:
+            # We only realize that we've reached the end of a token when we
+            # find a character that's not part of the current token - since
+            # that character may be part of the next token, it's stored in the
+            # charstack.
+            if self.charstack:
+                nextchar = self.charstack.pop(0)
+            else:
+                nextchar = self.instream.read(1)
+                while nextchar == "\x00":
+                    nextchar = self.instream.read(1)
+
+            if not nextchar:
+                self.eof = True
+                break
+            elif not state:
+                # First character of the token - determines if we're starting
+                # to parse a word, a number or something else.
+                token = nextchar
+                if self.isword(nextchar):
+                    state = "a"
+                elif self.isnum(nextchar):
+                    state = "0"
+                elif self.isspace(nextchar):
+                    token = " "
+                    break  # emit token
+                else:
+                    break  # emit token
+            elif state == "a":
+                # If we've already started reading a word, we keep reading
+                # letters until we find something that's not part of a word.
+                seenletters = True
+                if self.isword(nextchar):
+                    token += nextchar
+                elif nextchar == ".":
+                    token += nextchar
+                    state = "a."
+                else:
+                    self.charstack.append(nextchar)
+                    break  # emit token
+            elif state == "0":
+                # If we've already started reading a number, we keep reading
+                # numbers until we find something that doesn't fit.
+                if self.isnum(nextchar):
+                    token += nextchar
+                elif nextchar == "." or (nextchar == "," and len(token) >= 2):
+                    token += nextchar
+                    state = "0."
+                else:
+                    self.charstack.append(nextchar)
+                    break  # emit token
+            elif state == "a.":
+                # If we've seen some letters and a dot separator, continue
+                # parsing, and the tokens will be broken up later.
+                seenletters = True
+                if nextchar == "." or self.isword(nextchar):
+                    token += nextchar
+                elif self.isnum(nextchar) and token[-1] == ".":
+                    token += nextchar
+                    state = "0."
+                else:
+                    self.charstack.append(nextchar)
+                    break  # emit token
+            elif state == "0.":
+                # If we've seen at least one dot separator, keep going, we'll
+                # break up the tokens later.
+                if nextchar == "." or self.isnum(nextchar):
+                    token += nextchar
+                elif self.isword(nextchar) and token[-1] == ".":
+                    token += nextchar
+                    state = "a."
+                else:
+                    self.charstack.append(nextchar)
+                    break  # emit token
+
+        if state in ("a.", "0.") and (
+            seenletters or token.count(".") > 1 or token[-1] in ".,"
+        ):
+            lll = self._split_decimal.split(token)
+            token = lll[0]
+            for tok in lll[1:]:
+                if tok:
+                    self.tokenstack.append(tok)
+
+        if state == "0." and token.count(".") == 0:
+            token = token.replace(",", ".")
+
+        return token
+
+    def __iter__(self):
+        return self
+
+    def __next__(self):
+        token = self.get_token()
+        if token is None:
+            raise StopIteration
+
+        return token
+
+    def next(self):
+        return self.__next__()  # Python 2.x support
+
+    @classmethod
+    def split(cls, s):
+        return list(cls(s))
+
+    @classmethod
+    def isword(cls, nextchar):
+        """Whether or not the next character is part of a word"""
+        return nextchar.isalpha()
+
+    @classmethod
+    def isnum(cls, nextchar):
+        """Whether the next character is part of a number"""
+        return nextchar.isdigit()
+
+    @classmethod
+    def isspace(cls, nextchar):
+        """Whether the next character is whitespace"""
+        return nextchar.isspace()
+
+
 # Ugly copy and paste from dateutil.parser._parser._ymd with dayfirst modified to mean day is outer value
 # ie. dayfirst prefers dmy or ymd where in dateutil it prefers dmy and ydm!
 class _ymd(list):  # pragma: no cover
@@ -205,9 +375,7 @@ class _ymd(list):  # pragma: no cover
         )
 
         strids = {key: val for key, val in strids if val is not None}
-        if len(self) == len(strids) > 0 or (
-            len(self) == 3 and len(strids) == 2
-        ):
+        if len(self) == len(strids) > 0 or (len(self) == 3 and len(strids) == 2):
             return self._resolve_from_stridxs(strids)
 
         mstridx = self.mstridx
@@ -429,9 +597,7 @@ class DateParser(dateutil.parser.parser):  # pragma: no cover
                         skipped_idxs.append(i)
 
                 # Check for a timezone name
-                elif self._could_be_tzname(
-                    res.hour, res.tzname, res.tzoffset, l[i]
-                ):
+                elif self._could_be_tzname(res.hour, res.tzname, res.tzoffset, l[i]):
                     res.tzname = l[i]
                     res.tzoffset = info.tzoffset(res.tzname)
 
@@ -472,9 +638,7 @@ class DateParser(dateutil.parser.parser):  # pragma: no cover
                     else:
                         raise ValueError(timestr)
 
-                    res.tzoffset = signal * (
-                        hour_offset * 3600 + min_offset * 60
-                    )
+                    res.tzoffset = signal * (hour_offset * 3600 + min_offset * 60)
 
                     # Look for a timezone name between parenthesis
                     if (
@@ -483,9 +647,7 @@ class DateParser(dateutil.parser.parser):  # pragma: no cover
                         and l[i + 3] == "("
                         and l[i + 5] == ")"
                         and 3 <= len(l[i + 4])
-                        and self._could_be_tzname(
-                            res.hour, res.tzname, None, l[i + 4]
-                        )
+                        and self._could_be_tzname(res.hour, res.tzname, None, l[i + 4])
                     ):
                         # -0300 (BRST)
                         res.tzname = l[i + 4]
@@ -516,9 +678,7 @@ class DateParser(dateutil.parser.parser):  # pragma: no cover
             return None, None, None
 
         if fuzzy_with_tokens:
-            skipped_tokens, date_tokens = self._recombine_skipped_date(
-                l, skipped_idxs
-            )
+            skipped_tokens, date_tokens = self._recombine_skipped_date(l, skipped_idxs)
             return res, tuple(skipped_tokens), tuple(date_tokens)
         else:
             return res, None, None
@@ -619,9 +779,7 @@ def parse(
     """
 
     if default is None:
-        default = datetime.now().replace(
-            hour=0, minute=0, second=0, microsecond=0
-        )
+        default = datetime.now().replace(hour=0, minute=0, second=0, microsecond=0)
 
     res, skipped_tokens, date_tokens = DEFAULTPARSER._parse(timestr, **kwargs)
 
@@ -766,10 +924,7 @@ def parse_date_range(
                 ignoretz=ignoretz,
                 tzinfos=tzinfos,
             )
-        if (
-            startdate.year == default_sd_year
-            and enddate.year == default_ed_year
-        ):
+        if startdate.year == default_sd_year and enddate.year == default_ed_year:
             raise ParserError("No year in date!")
     else:
         try:
@@ -800,21 +955,13 @@ def parse_date_range(
             enddate = enddate.replace(month=default_enddate.month)
     if zero_time:
         if not max_starttime:
-            startdate = startdate.replace(
-                hour=0, minute=0, second=0, microsecond=0
-            )
+            startdate = startdate.replace(hour=0, minute=0, second=0, microsecond=0)
         if not max_endtime:
-            enddate = enddate.replace(
-                hour=0, minute=0, second=0, microsecond=0
-            )
+            enddate = enddate.replace(hour=0, minute=0, second=0, microsecond=0)
     if max_starttime:
-        startdate = startdate.replace(
-            hour=23, minute=59, second=59, microsecond=999999
-        )
+        startdate = startdate.replace(hour=23, minute=59, second=59, microsecond=999999)
     if max_endtime:
-        enddate = enddate.replace(
-            hour=23, minute=59, second=59, microsecond=999999
-        )
+        enddate = enddate.replace(hour=23, minute=59, second=59, microsecond=999999)
     if timezone_handling == 0:
         startdate = startdate.replace(tzinfo=timezone.utc)
         enddate = enddate.replace(tzinfo=timezone.utc)
@@ -949,9 +1096,7 @@ def get_timestamp_from_datetime(date: datetime) -> float:
             + date.microsecond / 1e6
         )
     else:
-        return (
-            date - datetime(1970, 1, 1, tzinfo=timezone.utc)
-        ).total_seconds()
+        return (date - datetime(1970, 1, 1, tzinfo=timezone.utc)).total_seconds()
 
 
 def get_datetime_from_timestamp(
